Index: ruby/branches/0.0/models/rm/data_types/basic.rb
===================================================================
--- ruby/branches/0.0/models/rm/data_types/basic.rb	(revision 167)
+++ ruby/branches/0.0/models/rm/data_types/basic.rb	(revision 168)
@@ -1,14 +1,14 @@
-module OpenEhr
+module OpenEHR
   module RM
-    module DataTypes
+    module Data_Types
       module Basic
-        module CanonicalFragment
+        module Canonical_Fragment
         end
 
-        class DataValue
-          include OpenEhr::RM::Support::Definition::BasicDefinition
+        class Data_Value
+          include OpenEHR::RM::Support::Definition::Basic_Definition
         end
 
-        class DvBoolean < DataValue
+        class DV_Boolean < Data_Value
           def initialize(value)
             check_not_nil(value)
@@ -32,7 +32,7 @@
             end
           end
-        end  # end of DvBoolean
+        end  # end of DV_Boolean
 
-        class DvState < DataValue
+        class DV_State < Data_Value
           attr_accessor :value
           attr_writer :terminal
@@ -47,7 +47,7 @@
             @terminal == true
           end
-        end # end of DvState
+        end # end of DV_State
 
-        class DvIdentifier
+        class DV_Identifier
           attr_accessor :issuer, :assigner, :id, :type
           def initialize(assigner, id, issuer, type)
@@ -60,5 +60,5 @@
             @type = type
           end
-        end #end of DvIdentifier
+        end #end of DV_Identifier
       end # end of Basic
     end # end of Data_types
Index: ruby/branches/0.0/models/rm/data_types/encapslated.rb
===================================================================
--- ruby/branches/0.0/models/rm/data_types/encapslated.rb	(revision 167)
+++ ruby/branches/0.0/models/rm/data_types/encapslated.rb	(revision 168)
@@ -1,7 +1,7 @@
-module OpenEhr
+module OpenEHR
   module RM
-    module DataTypes
+    module Data_Types
       module Encapsulated
-        class DvEncapsulated  < OpenEhr::RM::DataTypes::Basic::DataValue
+        class DV_Encapsulated  < OpenEHR::RM::Data_Types::Basic::Data_Value
           attr_accessor :charset, :language
           def size
@@ -13,8 +13,8 @@
           end
         end
-        class DvMultimedia < DvEncapsulated
+        class DV_Multimedia < DV_Encapsulated
           
         end
-        class DvParsable < DvEncapsulated
+        class DV_Parsable < DV_Encapsulated
           attr_reader :value, :formalism
           def initialize(value, formalism, charset = nil, language = nil)
Index: ruby/branches/0.0/models/rm/data_types/quantity/data_time.rb
===================================================================
--- ruby/branches/0.0/models/rm/data_types/quantity/data_time.rb	(revision 167)
+++ ruby/branches/0.0/models/rm/data_types/quantity/data_time.rb	(revision 168)
@@ -1,5 +1,5 @@
-module OpenEhr
+module OpenEHR
   module RM
-    module DataTypes
+    module Data_Types
       module Quantity
         module Date_
Index: ruby/branches/0.0/models/rm/data_types/time_specification.rb
===================================================================
--- ruby/branches/0.0/models/rm/data_types/time_specification.rb	(revision 167)
+++ ruby/branches/0.0/models/rm/data_types/time_specification.rb	(revision 168)
@@ -1,7 +1,7 @@
-module OpenEhr
+module OpenEHR
   module RM
-    module DataTypes
-      module TimeSpecification
-        class DvTimeSpecification < OpenEhr::RM::DataTypes::Basic::DataValue
+    module Data_Types
+      module Time_Specification
+        class DV_Time_Specification < OpenEHR::RM::Data_Types::Basic::Data_Value
           def initialize(value)
             @value = value
@@ -18,5 +18,5 @@
         end
         
-        class DvGeneralTimeSpecification < DvTimeSpecification
+        class DV_General_Time_Specification < DV_Time_Specification
           attr_reader :value
           def initialize(value)
@@ -34,5 +34,5 @@
         end
 
-        class DvPeriodicTimeSpecification < DvTimeSpecification
+        class DV_Periodic_Time_Specification < DV_Time_Specification
           attr_reader :value
           def initialize(value)
Index: ruby/branches/0.0/models/rm/data_types/uri.rb
===================================================================
--- ruby/branches/0.0/models/rm/data_types/uri.rb	(revision 167)
+++ ruby/branches/0.0/models/rm/data_types/uri.rb	(revision 168)
@@ -1,6 +1,6 @@
 require 'uri'
 #require 'uri/generic'
-module Uri
-  class Ehr < ::URI::Generic
+module URI
+  class EHR < ::URI::Generic
     COMPONENT = [
       :scheme, :path, :fragment, :query
@@ -17,11 +17,11 @@
     end
   end
-  @@schemes['EHR'] = Ehr
+  @@schemes['EHR'] = EHR
 end
-module OpenEhr
+module OpenEHR
   module RM
-    module DataTypes
-      module Uri
-        class DvUri < OpenEhr::RM::DataTypes::Basic::DataValue
+    module Data_Types
+      module URI
+        class DV_URI < OpenEHR::RM::Data_Types::Basic::Data_Value
           def initialize(value)
             raise ArgumentError, "value is empty" if value.nil?
@@ -51,5 +51,5 @@
           end
         end
-        class DvEhrUri < DvUri
+        class DV_EHR_URI < DV_URI
           def initialize(value)
             check_value(value)

Index: ruby/branches/0.0/models/rm/data_types/text.rb
===================================================================
--- ruby/branches/0.0/models/rm/data_types/text.rb	(revision 167)
+++ ruby/branches/0.0/models/rm/data_types/text.rb	(revision 168)
@@ -1,7 +1,7 @@
-module OpenEhr
+module OpenEHR
   module RM
-    module DataTypes
+    module Data_Types
       module Text
-        class TermMapping
+        class Term_Mapping
           attr_reader :match, :purpose, :target
           def initialize(match, purpose, target)
@@ -23,5 +23,5 @@
             match == '?'
           end
-          def TermMapping.is_valid_mach_code?(c)
+          def Term_Mapping.is_valid_mach_code?(c)
             c == '>' or c == '=' or c == '<' or c == '?'
           end
@@ -31,5 +31,5 @@
           end
           def purpose_valid(purpose)
-            if !purpose.nil? and !purpose.instance_of? DvCodedText
+            if !purpose.nil? and !purpose.instance_of? DV_Coded_Text
               raise ArgumentError, "purpose is not valid"
             end
@@ -41,5 +41,5 @@
         end
 
-        class CodePhrase
+        class Code_Phrase
           attr_reader :terminology_id, :code_string
           def initialize(terminology_id, code_string)
@@ -50,14 +50,14 @@
               raise Exception.new("empty codeString")
             end
-            if terminology_id.instance_of?(TerminologyId)
+            if terminology_id.instance_of?(Terminology_ID)
               @terminology_id = terminology_id
             else
-              @terminologyID = TerminologyId.new(terminology_id)
+              @terminologyID = Terminology_ID.new(terminology_id)
             end
             @code_string = code_string
           end
-        end # of CodePhrase
+        end # of Code_Phrase
 
-        class DvText < OpenEhr::RM::DataTypes::Basic::DataValue
+        class DV_Text < OpenEHR::RM::Data_Types::Basic::Data_Value
           attr_reader :value, :formatting, :hyperlink, :mappings
           attr_reader :language, :encoding
@@ -65,8 +65,8 @@
                          mappings = nil, language = nil, encoding = nil)
             value_valid(value)
-            DvText.formatting_valid(formatting)
-            DvText.encoding_valid(encoding)
-            DvText.mapping_valid(mappings)
-            DvText.language_valid(language)
+            DV_Text.formatting_valid(formatting)
+            DV_Text.encoding_valid(encoding)
+            DV_Text.mapping_valid(mappings)
+            DV_Text.language_valid(language)
             @value, @formatting, @encoding = value, formatting, encoding
             @mappings, @language = mappings, language
@@ -77,17 +77,17 @@
           end
           def formatting=(formatting)
-            DvText.formatting_valid(formatting)
+            DV_Text.formatting_valid(formatting)
             @formatting = formatting
           end
           def encoding=(encoding)
-            DvText.encoding_valid(encoding)
+            DV_Text.encoding_valid(encoding)
             @encoding = encoding
           end
           def mappings=(mappings)
-            DvText.mapping_valid(mappings)
+            DV_Text.mapping_valid(mappings)
             @mappings = mappings
           end
           def language=(language)
-            DvText.language_valid(language)
+            DV_Text.language_valid(language)
             @language = language
           end
@@ -96,5 +96,5 @@
             if value.nil? or value.empty? or value.include? CR or value.include? LF
               raise ArgumentError, "value is not valid"
               # CR and LF are defined in Basic_Definition inherited DataValue.
             end
           end
@@ -125,5 +125,5 @@
         end
 
-        class DvCodedText < DvText
+        class DV_Coded_Text < DV_Text
           attr_reader :defining_code
           def initialize(value, defining_code, formatting = nil, 
@@ -144,5 +144,5 @@
         end
 
-        class DvParagraph < OpenEhr::RM::DataTypes::Basic::DataValue
+        class DV_Paragraph < OpenEHR::RM::Data_Types::Basic::Data_Value
           attr_reader :items
           def initialize(items)
@@ -96,5 +96,5 @@
             if value.nil? or value.empty? or value.include? CR or value.include? LF
               raise ArgumentError, "value is not valid"
-              # CR and LF are defined in Basic_Definition inherited DataValue.
+              # CR and LF are defined in Basic_Definition inherited Data_Value.
             end
           end